pub struct VirtualPoolMetadata {
pub virtual_pool: Pubkey,
pub padding: [u128; 6],
pub name: String,
pub website: String,
pub logo: String,
}Fields
virtual_pool: Pubkeypadding: [u128; 6]name: Stringwebsite: Stringlogo: StringTrait Implementations
Sourceimpl BorshDeserialize for VirtualPoolMetadata
impl BorshDeserialize for VirtualPoolMetadata
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for VirtualPoolMetadata
impl CarbonDeserialize for VirtualPoolMetadata
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for VirtualPoolMetadata
impl Clone for VirtualPoolMetadata
Sourcefn clone(&self) -> VirtualPoolMetadata
fn clone(&self) -> VirtualPoolMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VirtualPoolMetadata
impl Debug for VirtualPoolMetadata
Sourceimpl<'de> Deserialize<'de> for VirtualPoolMetadata
impl<'de> Deserialize<'de> for VirtualPoolMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for VirtualPoolMetadata
Sourceimpl Hash for VirtualPoolMetadata
impl Hash for VirtualPoolMetadata
Sourceimpl PartialEq for VirtualPoolMetadata
impl PartialEq for VirtualPoolMetadata
Sourcefn eq(&self, other: &VirtualPoolMetadata) -> bool
fn eq(&self, other: &VirtualPoolMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for VirtualPoolMetadata
impl Serialize for VirtualPoolMetadata
impl StructuralPartialEq for VirtualPoolMetadata