pub struct CreateClaimFeeOperator {}Trait Implementations
Sourceimpl ArrangeAccounts for CreateClaimFeeOperator
impl ArrangeAccounts for CreateClaimFeeOperator
type ArrangedAccounts = CreateClaimFeeOperatorInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for CreateClaimFeeOperator
impl BorshDeserialize for CreateClaimFeeOperator
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for CreateClaimFeeOperator
impl CarbonDeserialize for CreateClaimFeeOperator
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for CreateClaimFeeOperator
impl Clone for CreateClaimFeeOperator
Sourcefn clone(&self) -> CreateClaimFeeOperator
fn clone(&self) -> CreateClaimFeeOperator
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateClaimFeeOperator
impl Debug for CreateClaimFeeOperator
Sourceimpl<'de> Deserialize<'de> for CreateClaimFeeOperator
impl<'de> Deserialize<'de> for CreateClaimFeeOperator
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CreateClaimFeeOperator
Sourceimpl Hash for CreateClaimFeeOperator
impl Hash for CreateClaimFeeOperator
Sourceimpl PartialEq for CreateClaimFeeOperator
impl PartialEq for CreateClaimFeeOperator
Sourcefn eq(&self, other: &CreateClaimFeeOperator) -> bool
fn eq(&self, other: &CreateClaimFeeOperator) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CreateClaimFeeOperator
impl Serialize for CreateClaimFeeOperator
impl StructuralPartialEq for CreateClaimFeeOperator