pub struct EvtInitializePoolEvent {
pub pool: Pubkey,
pub config: Pubkey,
pub creator: Pubkey,
pub base_mint: Pubkey,
pub pool_type: u8,
pub activation_point: u64,
}Fields
pool: Pubkeyconfig: Pubkeycreator: Pubkeybase_mint: Pubkeypool_type: u8activation_point: u64Trait Implementations
Sourceimpl BorshDeserialize for EvtInitializePoolEvent
impl BorshDeserialize for EvtInitializePoolEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for EvtInitializePoolEvent
impl CarbonDeserialize for EvtInitializePoolEvent
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for EvtInitializePoolEvent
impl Clone for EvtInitializePoolEvent
Sourcefn clone(&self) -> EvtInitializePoolEvent
fn clone(&self) -> EvtInitializePoolEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvtInitializePoolEvent
impl Debug for EvtInitializePoolEvent
Sourceimpl<'de> Deserialize<'de> for EvtInitializePoolEvent
impl<'de> Deserialize<'de> for EvtInitializePoolEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EvtInitializePoolEvent
Sourceimpl Hash for EvtInitializePoolEvent
impl Hash for EvtInitializePoolEvent
Sourceimpl PartialEq for EvtInitializePoolEvent
impl PartialEq for EvtInitializePoolEvent
Sourcefn eq(&self, other: &EvtInitializePoolEvent) -> bool
fn eq(&self, other: &EvtInitializePoolEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for EvtInitializePoolEvent
impl Serialize for EvtInitializePoolEvent
impl StructuralPartialEq for EvtInitializePoolEvent