pub struct ProtocolWithdrawSurplus {}Trait Implementations
Sourceimpl ArrangeAccounts for ProtocolWithdrawSurplus
impl ArrangeAccounts for ProtocolWithdrawSurplus
type ArrangedAccounts = ProtocolWithdrawSurplusInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for ProtocolWithdrawSurplus
impl BorshDeserialize for ProtocolWithdrawSurplus
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for ProtocolWithdrawSurplus
impl CarbonDeserialize for ProtocolWithdrawSurplus
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for ProtocolWithdrawSurplus
impl Clone for ProtocolWithdrawSurplus
Sourcefn clone(&self) -> ProtocolWithdrawSurplus
fn clone(&self) -> ProtocolWithdrawSurplus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProtocolWithdrawSurplus
impl Debug for ProtocolWithdrawSurplus
Sourceimpl<'de> Deserialize<'de> for ProtocolWithdrawSurplus
impl<'de> Deserialize<'de> for ProtocolWithdrawSurplus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProtocolWithdrawSurplus
Sourceimpl Hash for ProtocolWithdrawSurplus
impl Hash for ProtocolWithdrawSurplus
Sourceimpl PartialEq for ProtocolWithdrawSurplus
impl PartialEq for ProtocolWithdrawSurplus
Sourcefn eq(&self, other: &ProtocolWithdrawSurplus) -> bool
fn eq(&self, other: &ProtocolWithdrawSurplus) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProtocolWithdrawSurplus
impl Serialize for ProtocolWithdrawSurplus
impl StructuralPartialEq for ProtocolWithdrawSurplus